.. pypom_form documentation master file, created by
   sphinx-quickstart on Tue Sep 13 16:37:58 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ./README.rst

Index
----------

.. toctree::
    :maxdepth: 2

    pypom_form <README>
    Advanced usage with examples <advanced>
    API <api>
    Contributors <contributors>
    Changelog <changes>

.. _py.test: https://github.com/pytest-dev/pytest
.. _pytest-splinter: https://github.com/pytest-dev/pytest-splinter
.. _pytest-bdd: https://github.com/pytest-dev/pytest-bdd
